
import { Req } from '../http/request';
import { UserData } from '../storage';
import { HttpConfig } from '../http/server';
import { HttpWebDependencies } from './server';
import { ErrorCode, ErrorInfo } from '../http/send-error';
import { csp_headers } from '../http/content-security-policy';
import { FastifyInstance, RouteShorthandOptions } from 'fastify';

export function register_root_page_endpoint(http_server: FastifyInstance, conf: HttpConfig, { session, logger }: HttpWebDependencies) {
	const opts: RouteShorthandOptions = {
		schema: { },
	};

	http_server.get('/', opts, async (req: Req, res) => {
		try {
			await session.check_login(req);
		}

		catch (error) {
			session.reset(res);
		}

		res.status(200);
		res.header('content-type', 'text/html; charset=utf-8');
		csp_headers(res, conf.exposed_url);
		return render_root_page(req.session?.user);
	});
}

export const render_root_page = (user?: UserData, error_code?: ErrorCode, error?: ErrorInfo) => `<!doctype html>
<html>
<head>
<title>Node.js + TypeScript Service</title>
</head>
<body>
<h1>Node.js + TypeScript Service</h1>
${user
? `<p>Logged in as ${user.name} (${user.username})</p>
<form action="/logout" method="POST">
<button type="submit">Logout</button>
</form>`
: '<a href="/login">Login Page</a>'}
</body>
</html>
`;
